==> dcoupon_sdk_flutter_package-1.0.4.tar.gz: lib/src/data/datasources/coupon_remote_data_sources.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/coupons_api_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/coupon_create_user_coupons_request.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/coupon_get_coupons_query.dart';
import 'package:dio/dio.dart';

abstract class CouponRemoteDataSource {
  Future<Either<Failure, dynamic>> getCoupons({
    int offset,
    int limit,
    String sortBy,
    List<String> companyTokens,
    List<String> retailerTokens,
  });

  Future<Either<Failure, dynamic>> createUserCoupons({
    List<String> promotionTokens,
    String latitude,
    String longitude,
    String source,
    String transId,
    String crmId,
    String publisherName,
  });

  Future<Either<Failure, dynamic>> getCouponDetail({
    String couponId,
  });

  Future<Either<Failure, dynamic>> activateCoupon({
    String couponId,
  });

  Future<Either<Failure, dynamic>> deactivateCoupon({
    String couponId,
  });

  Future<Either<Failure, dynamic>> getUserCouponsRetailers();

  Future<Either<Failure, dynamic>> getUserCouponsCompanies();
}

class CouponRemoteDataSourceImpl implements CouponRemoteDataSource {
  Dio dio = Dio();
  // ..interceptors.add(LoggingInterceptor());

  @override
  Future<Either<Failure, dynamic>> getCoupons({
    int offset,
    int limit,
    String sortBy,
    List<String> companyTokens,
    List<String> retailerTokens,
  }) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    final queryParameters = CouponGetCouponsQuery(
      offset: offset,
      limit: limit,
      sortBy: sortBy,
      companyTokens: companyTokens,
      retailerTokens: retailerTokens,
      lang: ConfigReader.languageCode,
      country: ConfigReader.clientCountry,
    );

    try {
      final response = await dio.get(
        CouponsApiHelper.getCouponsListUrl(),
        queryParameters: queryParameters.toJson(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> createUserCoupons({
    List<String> promotionTokens,
    String latitude,
    String longitude,
    String source,
    String transId,
    String crmId,
    String publisherName,
  }) async {
    // dio.interceptors.add(LoggingInterceptor());
    dio.options.headers = CouponsApiHelper.buildHeaders();

    final publisherId = ConfigReader.getPublisherTokenByName(publisherName);
    final couponCreateUserCouponsRequest = CouponCreateUserCouponsRequest(
      promotionTokens: promotionTokens,
      latitude: latitude,
      longitude: longitude,
      source: source,
      transId: transId,
      crmId: crmId,
      publisherId: publisherId,
    );

    try {
      final response = await dio.post(
        CouponsApiHelper.getCreateUserCouponsUrl(),
        data: couponCreateUserCouponsRequest.toJson(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> activateCoupon({
    String couponId,
  }) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.post(
        CouponsApiHelper.getActivateCouponUrl(couponId),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> deactivateCoupon({String couponId}) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.post(
        CouponsApiHelper.getDeactivateCouponUrl(couponId),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getCouponDetail({String couponId}) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        CouponsApiHelper.getCouponDetailUrl(couponId),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserCouponsCompanies() async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        CouponsApiHelper.getUserCouponsCompanies(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserCouponsRetailers() async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        CouponsApiHelper.getUserCouponsRetailers(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }
}

==> dcoupon_sdk_flutter_package-1.1.3.tar.gz: lib/src/data/datasources/coupon_remote_data_sources.dart <==
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/exceptions.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/coupons_api_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/coupon_create_user_coupons_request.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/models/coupon_get_coupons_query.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dio/dio.dart';

abstract class CouponRemoteDataSource {
  Future<Either<Failure, dynamic>> getCoupons({
    int offset,
    int limit,
    String sortBy,
    List<String> companyTokens,
    List<String> retailerTokens,
  });

  Future<Either<Failure, dynamic>> createUserCoupons({
    List<String> promotionTokens,
    String latitude,
    String longitude,
    String source,
    String transId,
    String crmId,
    String publisherName,
  });

  Future<Either<Failure, dynamic>> getCouponDetail({
    String couponId,
  });

  Future<Either<Failure, dynamic>> activateCoupon({
    String couponId,
  });

  Future<Either<Failure, dynamic>> deactivateCoupon({
    String couponId,
  });

  Future<Either<Failure, dynamic>> getUserCouponsRetailers();

  Future<Either<Failure, dynamic>> getUserCouponsCompanies();
}

class CouponRemoteDataSourceImpl implements CouponRemoteDataSource {
  Dio dio = Dio();
  // ..interceptors.add(LoggingInterceptor());

  @override
  Future<Either<Failure, dynamic>> getCoupons({
    int offset,
    int limit,
    String sortBy,
    List<String> companyTokens,
    List<String> retailerTokens,
  }) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    final queryParameters = CouponGetCouponsQuery(
      offset: offset,
      limit: limit,
      sortBy: sortBy,
      retailerTokens: ConfigReader.clientType != ClientType.RETAILER ? retailerTokens : [ConfigReader.clientApiToken],
      companyTokens: ConfigReader.clientType != ClientType.COMPANY ? companyTokens : [ConfigReader.clientApiToken],
      lang: ConfigReader.languageCode,
      country: ConfigReader.clientCountry,
    );

    try {
      final response = await dio.get(
        CouponsApiHelper.getCouponsListUrl(),
        queryParameters: queryParameters.toJson(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> createUserCoupons({
    List<String> promotionTokens,
    String latitude,
    String longitude,
    String source,
    String transId,
    String crmId,
    String publisherName,
  }) async {
    // dio.interceptors.add(LoggingInterceptor());
    dio.options.headers = CouponsApiHelper.buildHeaders();

    final publisherId = ConfigReader.getPublisherTokenByName(publisherName);

    final customSource = source != null ? '${ConfigReader.clientApiToken}#$source' : ConfigReader.clientApiToken;
    final sourceMaxLength = 45; //VARCHAR(45) in DDBB

    final couponCreateUserCouponsRequest = CouponCreateUserCouponsRequest(
      promotionTokens: promotionTokens,
      latitude: latitude,
      longitude: longitude,
      source: customSource.length <= sourceMaxLength ? customSource : customSource.substring(0, 45), 
      transId: transId,
      crmId: crmId,
      publisherId: publisherId,
    );

    try {
      final response = await dio.post(
        CouponsApiHelper.getCreateUserCouponsUrl(),
        data: couponCreateUserCouponsRequest.toJson(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> activateCoupon({
    String couponId,
  }) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.post(
        CouponsApiHelper.getActivateCouponUrl(couponId),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> deactivateCoupon({String couponId}) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.post(
        CouponsApiHelper.getDeactivateCouponUrl(couponId),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getCouponDetail({String couponId}) async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        CouponsApiHelper.getCouponDetailUrl(couponId),
        queryParameters: {
          "lang": ConfigReader.languageCode,
        }
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserCouponsCompanies() async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        CouponsApiHelper.getUserCouponsCompanies(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }

  @override
  Future<Either<Failure, dynamic>> getUserCouponsRetailers() async {
    dio.options.headers = CouponsApiHelper.buildHeaders();

    try {
      final response = await dio.get(
        CouponsApiHelper.getUserCouponsRetailers(),
      );
      return Right(response.data);
    } on DioError catch (e) {
      if (e.type == DioErrorType.RESPONSE) {
        return Left(ServerFailure(httpStatus: e.response.statusCode));
      } else {
        throw ServerException(e.message);
      }
    }
  }
}
